import {
  IsInt,
  IsNotEmpty
} from "class-validator";
import { Column, Entity, ManyToOne, PrimaryGeneratedColumn } from "typeorm";
import { PermissionAction } from '../enums/PermissionAction';
import { PermissionTarget } from '../enums/PermissionTargets';
import { Principal } from './Principal';
/**
 * Defines the Permission interface.
*/
@Entity()
export abstract class Permission {
  /**
   * Autogenerated unique id (primary key).
   */
  @PrimaryGeneratedColumn()
  @IsInt()
  id: number;

  /**
   * The permissions principal
   */
  @ManyToOne(() => Principal, principal => principal.permissions)
  principal: Principal;

  /**
   * The target
   */
  @Column({ type: 'varchar' })
  @IsNotEmpty()
  target: PermissionTarget;

  /**
   * The action type
   */
  @Column({ type: 'varchar' })
  action: PermissionAction;
}